==> eric4-4.4.20.tbz: lib/python2.7/site-packages/eric4config.py <==
# -*- coding: utf-8 -*-
#
# This module contains the configuration of the individual eric4 installation
#

_pkg_config = {
    'ericDir'              : r'/usr/local/lib/python2.7/site-packages/eric4',
    'ericPixDir'           : r'/usr/local/lib/python2.7/site-packages/eric4/pixmaps',
    'ericIconDir'          : r'/usr/local/lib/python2.7/site-packages/eric4/icons',
    'ericDTDDir'           : r'/usr/local/lib/python2.7/site-packages/eric4/DTDs',
    'ericCSSDir'           : r'/usr/local/lib/python2.7/site-packages/eric4/CSSs',
    'ericStylesDir'        : r'/usr/local/lib/python2.7/site-packages/eric4/Styles',
    'ericDocDir'           : r'/usr/local/share/doc/eric4',
    'ericExamplesDir'      : r'/usr/local/share/examples/eric4',
    'ericTranslationsDir'  : r'/usr/local/lib/python2.7/site-packages/eric4/i18n',
    'ericTemplatesDir'     : r'/usr/local/lib/python2.7/site-packages/eric4/DesignerTemplates',
    'ericCodeTemplatesDir' : r'/usr/local/lib/python2.7/site-packages/eric4/CodeTemplates',
    'ericOthersDir'        : r'/usr/local/lib/python2.7/site-packages/eric4',
    'bindir'               : r'/usr/local/bin',
    'mdir'                 : r'/usr/local/lib/python2.7/site-packages',
    'apidir'               : r'/usr/local/share/qt4/qsci/api',
    'apis'                 : ['zope-3.3.1.api', 'eric4.api', 'zope-2.11.2.api', 'zope-2.10.7.api', 'eric4.api', 'Ruby-1.8.7.api'],
}

def getConfig(name):
    '''
    Module function to get a configuration value.

    @param name the name of the configuration value (string).
    '''
    try:
        return _pkg_config[name]
    except KeyError:
        pass

    raise AttributeError, '"%s" is not a valid configuration value' % name

==> eric4-4.5.7.tbz: lib/python2.7/site-packages/eric4config.py <==
# -*- coding: utf-8 -*-
#
# This module contains the configuration of the individual eric4 installation
#

_pkg_config = {
    'ericDir'              : r'/usr/local/lib/python2.7/site-packages/eric4',
    'ericPixDir'           : r'/usr/local/lib/python2.7/site-packages/eric4/pixmaps',
    'ericIconDir'          : r'/usr/local/lib/python2.7/site-packages/eric4/icons',
    'ericDTDDir'           : r'/usr/local/lib/python2.7/site-packages/eric4/DTDs',
    'ericCSSDir'           : r'/usr/local/lib/python2.7/site-packages/eric4/CSSs',
    'ericStylesDir'        : r'/usr/local/lib/python2.7/site-packages/eric4/Styles',
    'ericDocDir'           : r'/usr/local/share/doc/eric4',
    'ericExamplesDir'      : r'/usr/local/share/examples/eric4',
    'ericTranslationsDir'  : r'/usr/local/lib/python2.7/site-packages/eric4/i18n',
    'ericTemplatesDir'     : r'/usr/local/lib/python2.7/site-packages/eric4/DesignerTemplates',
    'ericCodeTemplatesDir' : r'/usr/local/lib/python2.7/site-packages/eric4/CodeTemplates',
    'ericOthersDir'        : r'/usr/local/lib/python2.7/site-packages/eric4',
    'bindir'               : r'/usr/local/bin',
    'mdir'                 : r'/usr/local/lib/python2.7/site-packages',
    'apidir'               : r'/usr/local/share/qt4/qsci/api',
    'apis'                 : ['eric4.api', 'zope-2.11.2.api', 'zope-3.3.1.api', 'zope-2.10.7.api', 'eric4.api', 'Ruby-1.8.7.api'],
}

def getConfig(name):
    '''
    Module function to get a configuration value.

    @param name the name of the configuration value (string).
    '''
    try:
        return _pkg_config[name]
    except KeyError:
        pass

    raise AttributeError, '"%s" is not a valid configuration value' % name
